@@ -1,4 +1,4 @@
-pub mod packet;
+pub mod socket;
 pub mod stream;
 
 pub use snow;
@@ -6,15 +6,14 @@ pub use snow::params::NoiseParams;
 pub use snow::Builder;
 pub use snow::Keypair;
 
-pub use packet::NoisePacket;
-pub use packet::PacketPoller;
+pub use socket::NoiseSocket;
+pub use socket::PacketPoller;
 pub use stream::NoiseStream;
 
 use thiserror::Error;
 
 const TAG_LEN: usize = 16;
-const MAX_FRAME_LEN: usize = 0xffff;
-const HANDSHAKE_FRAME_LEN: usize = 1024;
+const MAX_MESSAGE_LEN: usize = u16::MAX as usize;
 
 #[derive(Debug, Error)]
 pub enum Error {
